/**
 * DanTheCoder - Innovative Web Solutions
 *
 * @author  DanTheCoder
 * @link    http://danthecoder.com
*/

// Initialization
var dtcApp = new Framework7({
    material: dtcwm_vars.is_material ? true : false,
	hideNavbarOnPageScroll: true,
	hideToolbarOnPageScroll: true,
	scrollTopOnNavbarClick: true,
    ajaxLinks: 'a.dtcwm-ajax',
    panelLeftBreakpoint: 768,
    swipePanel: 'left',
    swipePanelCloseOpposite: false
});

// Add view
var mainView = dtcApp.addView('.view-main', {});

// Prevent Checkout form submission from firing using aJax
jQuery('form.checkout').on('submit', function(e){
    //e.preventDefault();
    //e.stopPropagation();
    //e.stopImmediatePropagation();
    //console.log(e);
});


/**
 * Define jQuery
 */
jQuery( function( $ ) {

    var documentOnReady = {
        // Initialize 
        init: function(){
            documentOnReady.defaults();
            documentOnReady.quantity_buttons();
            documentOnReady.woocommerce_override();
            documentOnReady.toogle_shipping();
            documentOnReady.dynamic_toolbars();
        },


        /**
         * Default options
        */
        defaults: function() {
            $('input, textarea').on("focus", function() {
                mainView.hideToolbar();
            });

            $('input, textarea').on("focusout", function() {
                mainView.showToolbar();
            });

            // Disable GO button on specific inputs
            $('.hide-keypad input, .hide-keypad textarea').keypress(function(e) {
                if ( e.which == 13 ) {
                    $(this).blur();
                    e.preventDefault();
                }
            });

            // Update swiper slider on product related tab
            $('#related_tab').on('tab:show', function () {
                var relatedSwipers = $(this).find('.swiper-container');

                if ( relatedSwipers[0] ) {
                    relatedSwipers[0].swiper.update();
                }

                if ( relatedSwipers[1] ) {
                    relatedSwipers[1].swiper.update();
                }
            });

        },


        /**
         * Quantity inputs buttons
        */
        quantity_buttons: function() {
            $('.plus').on('click', function(e) {
                var val = parseInt($(this).prev('input').val());
                $(this).prev('input').val( val+1 ).change();
            });

            $('.minus').on('click', function(e) {
                var val = parseInt($(this).next('input').val());
                if (val !== 0) {
                    $(this).next('input').val( val-1 ).change();
                } 
            });
        },


        /**
         * WooCommerce Custom Code
        */
        woocommerce_override: function() {
            // Always enable cart update button
            $( '.woocommerce-cart-form input[name="update_cart"]' ).removeProp( 'disabled' );
            
            // Ajax add to cart.
            $( document ).on( 'click', '.add_to_cart_button', function() {
                dtcApp.showProgressbar($('body'), 'multi');
            });

            // Added to cart
            $( document.body ).on( 'added_to_cart', function() {

                dtcApp.hideProgressbar($('body'), 'multi');

                // Show notification
                dtcApp.addNotification({
                    title: dtcwm_vars.i18n_added_to_cart_title,
                    message: dtcwm_vars.i18n_added_to_cart_msg,        
                    button: {
                        text: dtcwm_vars.i18n_added_to_cart_btn
                    }
                });

            });

        },


        /**
         * Checkout toogle shipping address
        */
        toogle_shipping: function() {
            // Check shipping checkbox
            var isChecked = $('#shipping-selected').prop('checked');
            if ( isChecked ) {
                $('.shipping_address').show();
            } else {
                $('.shipping_address').hide();
            }

            // Shipping on change event
            $('#shipping-selected').change(function() {
                if ( this.checked == true ) {
                    $('.shipping_address').show();
                } else {
                    $('.shipping_address').hide();
                }
            });
        },


        /**
         * Dynamic Toolbars 
        */
        dynamic_toolbars: function() {

            // Checkout - On click events
            $('#show_payment_tab').on('click', function () {
                dtcApp.showTab('#payment_tab');
                $('#show_payment_tab').hide();
                $('#show_confirm_tab').show();
            });

            $('#show_confirm_tab').on('click', function () {
                dtcApp.showTab('#confirm_tab');
                $('#show_payment_tab').hide();
                $('#show_confirm_tab').hide();
                $('#show_complete_btn').show();
            });

            // Checkout - On change event
            $('#billing_tab').on('tab:show', function () {
                $('#show_payment_tab').show();
                $('#show_confirm_tab').hide();
                $('#show_complete_btn').hide();
            });

            $('#payment_tab').on('tab:show', function () {
                $('#show_payment_tab').hide();
                $('#show_confirm_tab').show();
                $('#show_complete_btn').hide();
            });

            $('#confirm_tab').on('tab:show', function () {
                $('#show_payment_tab').hide();
                $('#show_confirm_tab').hide();
                $('#show_complete_btn').show();
            });
        }

    }

    $(document).ready( documentOnReady.init );

});