<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * DanTheCoder - Innovative Web Solutions
 *
 * @author  DanTheCoder
 * @link    http://danthecoder.com
*/

if ( ! class_exists( 'DTCWM_WooCommerce' ) ) {

    class DTCWM_WooCommerce {

        public function __construct() {
            add_action( 'after_setup_theme', array( $this, 'setup_woocommerce' ) );
            add_action( 'wp_enqueue_scripts', array( $this, 'script_cleaner' ), 100 );
            add_filter( 'woocommerce_product_tabs', array( $this, 'product_tabs'), 98 );
            add_filter( 'comment_post_redirect', array( $this, 'redirect_after_comment'), 10, 2 );
            add_filter( 'wc_add_to_cart_message_html', array( $this, 'add_to_cart_message') );
            add_filter('woocommerce_add_to_cart_fragments', array( $this, 'update_cart_total') );
        }


        /**
         * Sets up WooCommerce defaults and registers support for various features
        */
        public function setup_woocommerce() {

            // Add WooCommerce to the theme
            add_theme_support( 'woocommerce' );

            // Cart Hooks
            remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );

            // Shop Hooks
            remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
            remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
            remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
            remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

            remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
            add_action( 'woomobify_product_sorting', 'woocommerce_catalog_ordering', 30 );

            // Single Product Hooks
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
            add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 15 );
            
            // Hook the review template to out custom action
            add_action( 'woomobify_wc_product_review', 'comments_template', 50 );
            
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
            add_action( 'woomobify_wc_product_related', 'woocommerce_upsell_display', 5);
            add_action( 'woomobify_wc_product_related', 'woocommerce_output_related_products', 10);
        
            // Checkout Hooks
            remove_action( 'woocommerce_checkout_order_review', 'woocommerce_checkout_payment', 20 );
            add_action( 'woomobify_wc_checkout_payment', 'woocommerce_checkout_payment', 10 );

            remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_login_form', 10 );
            remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_coupon_form', 10 );
            
            global $settings_options;

            // disable add to cart button
            if ( false == $settings_options['catalog']['add_to_cart'] ) {
                remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
            }
          
        }


        /**
         * Ensure cart contents update when products are added to the cart via AJAX
        */
        public function update_cart_total( $fragments ) {
            global $woocommerce;
            
            ob_start(); ?>

            <span class="cart-badge"><?php echo sprintf( '%d', $woocommerce->cart->cart_contents_count ); ?></span>
            
            <?php
            
            $fragments['.cart-badge'] = ob_get_clean();
            
            return $fragments;
        }


        /**
         * Remove all unnecessary JS and CSS files
        */
        public function script_cleaner() {
            // Scripts
            wp_dequeue_script( 'select2');
            wp_deregister_script('select2');

            // Styles
            wp_dequeue_style( 'select2' );
            wp_deregister_style( 'select2' );

            wp_dequeue_style( 'woocommerce-twenty-seventeen' );
            wp_deregister_style( 'woocommerce-twenty-seventeen' );

            wp_dequeue_style( 'woocommerce-general');
            wp_deregister_style( 'woocommerce-general' );

            wp_dequeue_style( 'woocommerce-smallscreen' );
            wp_deregister_style( 'woocommerce-smallscreen' );

            wp_dequeue_style( 'woocommerce-layout' );
            wp_deregister_style( 'woocommerce-layout' );
        }


        /**
         * Product Tabs
         * Remove WooCommerce single product tabs
        */
        public function product_tabs( $tabs ) {
            unset( $tabs['description'] );              // Remove the description tab
            unset( $tabs['reviews'] );                  // Remove the reviews tab
            unset( $tabs['additional_information'] );   // Remove the additional information tab

            return $tabs;
        }


        /**
         * Comment Redirect
         * Redirect the user to the product instead of the comment ID
        */
        public function redirect_after_comment( $location, $comment ){
            $post_id = $comment->comment_post_ID;

            if( 'product' == get_post_type( $post_id ) ){
                $location = wp_get_referer();
            }
            return $location;
        }


        /**
         * Custom add to cart message
        */
        public function add_to_cart_message() {
            $message = esc_html__( 'This item was successfully added to your cart.', 'woomobify' );
            return $message;
        }

    }
}

return new DTCWM_WooCommerce();