<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * DanTheCoder - Innovative Web Solutions
 *
 * @author  DanTheCoder
 * @link    http://danthecoder.com
*/

if ( ! class_exists( 'DTC_WooMobify_Theme' ) ) {

    class DTC_WooMobify_Theme {

        public function __construct() {
            global $settings_options;

            add_action( 'after_setup_theme', array( $this, 'initialize' ) );
            add_action( 'wp_enqueue_scripts', array( $this, 'add_assets' ) );
            add_filter( 'body_class', array( $this, 'body_classes' ) );
            add_action( 'wp_head', array( $this, 'head_contents') );
            add_action( 'wp_head', array( $this, 'custom_css'), 100 );
            add_action( 'wp_head', array( $this, 'analytics_code'), 100 );
            add_action( 'wp_footer', array( $this, 'custom_js'), 100 );
        }


        /**
         * Sets up theme defaults and registers support for various features
         *
         * Note: the first-loaded translation file overrides any following ones if the same translation is present.
         */
        public function initialize() {
            global $settings_options;
            
            // Hide admin bar
            add_filter('show_admin_bar', '__return_false');

            // Load Localization files
            load_theme_textdomain( 'woomobify', trailingslashit( WP_LANG_DIR ) . 'themes/' );
            load_theme_textdomain( 'woomobify', get_template_directory() . '/languages' );
        
            // Clean up the head
            if ( $settings_options['clean_head'] ) {
                remove_action( 'wp_head', 'rsd_link' );
                remove_action( 'wp_head', 'wp_generator' );

                remove_action( 'wp_head', 'feed_links', 2 );
                remove_action( 'wp_head', 'feed_links_extra', 3 );
                remove_action( 'wp_head', 'wp_resource_hints', 2);

                remove_action( 'wp_head', 'index_rel_link' );
                remove_action( 'wp_head', 'wlwmanifest_link' );
                remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
                remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
                remove_action( 'wp_head', 'adjacent_posts_rel_link', 10, 0 );
                remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );

                remove_action( 'wp_head', 'wp_shortlink_wp_head', 10, 0 );
                remove_action( 'wp_head', 'rel_canonical' );
                remove_action( 'wp_head', 'rest_output_link_wp_head', 10 );

                remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
                remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
                remove_action( 'wp_print_styles', 'print_emoji_styles' );
                remove_action( 'admin_print_styles', 'print_emoji_styles' );

                remove_action( 'rest_api_init', 'wp_oembed_register_route' );
                remove_filter( 'oembed_dataparse', 'wp_filter_oembed_result', 10 );
                remove_action( 'wp_head', 'wp_oembed_add_discovery_links' );
                remove_action( 'wp_head', 'wp_oembed_add_host_js' );
            }
        }


        /**
         * Enqueue CSS & JS files
        */
        public function add_assets() {
            global $settings_options;

            if( dtcwm_is_material() ) {        
                wp_enqueue_style( 'woomobify-material', get_template_directory_uri() . '/assets/fw7/css/material/framework7.material.min.css', '', '', 'screen' );
                if ( $settings_options['enable_rtl'] ) {
                    wp_enqueue_style( 'woomobify-material-rtl', get_template_directory_uri() . '/assets/fw7/css/material/framework7.material.rtl.min.css', '', '', 'screen' );
                }
            } else {
                wp_enqueue_style( 'woomobify-ios', get_template_directory_uri() . '/assets/fw7/css/ios/framework7.ios.min.css', '', '', 'screen' );
                if ( $settings_options['enable_rtl'] ) {
                    wp_enqueue_style( 'woomobify-ios-rtl', get_template_directory_uri() . '/assets/fw7/css/ios/framework7.ios.rtl.min.css', '', '', 'screen' );
                }
            }

            wp_enqueue_style( 'woomobify-style', get_template_directory_uri() . '/assets/css/master.css', '', '', 'screen' );

            wp_enqueue_script( 'woomobify-fw7-js', get_template_directory_uri() . '/assets/fw7/js/framework7.min.js', '', false, true );
            wp_enqueue_script( 'woomobify-app-js', get_template_directory_uri() . '/assets/js/wm-app.js', '', false, true );

            wp_localize_script( 'woomobify-app-js', 'dtcwm_vars', array(
                'is_material' => dtcwm_is_material(),
                'i18n_added_to_cart_title' => esc_html__( 'Heads Up!', 'woomobify' ),
                'i18n_added_to_cart_msg' => esc_html__( 'This item was successfully added to your cart.', 'woomobify' ),
                'i18n_added_to_cart_btn' => esc_html__( 'Ok', 'woomobify' )
            ) );
        }


        /**
         * Body Classes
         * Add classes the all the pages body tag
        */
        public function body_classes( $classes ) {
            global $settings_options;

            if ( dtcwm_is_material() ) {
                $classes[] = 'is-material';
            } else {
                $classes[] = 'is-ios';
            }

            if ( $settings_options['enable_rtl'] ) {
                $classes[] = 'rtl';
            }
            
            return $classes;
        }


        /**
         * Custom styling from color scheme 
         * and also custom CSS option
         */
        public function head_contents() {
            global $settings_options;
            $favicon = $settings_options['favicon']['url'].''.$settings_options['favicon']['name'];

            ob_start();
            ?>

            <meta name="theme-color" content="<?= $settings_options['color_scheme']['address_bar']; ?>">
            <meta name="msapplication-navbutton-color" content="<?= $settings_options['color_scheme']['address_bar']; ?>">
            <meta name="apple-mobile-web-app-capable" content="yes">
            <meta name="apple-mobile-web-app-status-bar-style" content="black-translucent">

            <title><?= get_bloginfo('description'); ?> - <?= $settings_options['site_name']; ?></title>

            <?php if ( $favicon ) { ?>  
            <link rel="apple-touch-icon" sizes="57x57" href="<?= $favicon; ?>-57x57.png">
            <link rel="apple-touch-icon" sizes="60x60" href="<?= $favicon; ?>-60x60.png">
            <link rel="apple-touch-icon" sizes="72x72" href="<?= $favicon; ?>-72x72.png">
            <link rel="apple-touch-icon" sizes="76x76" href="<?= $favicon; ?>-76x76.png">
            <link rel="apple-touch-icon" sizes="114x114" href="<?= $favicon; ?>-114x114.png">
            <link rel="apple-touch-icon" sizes="120x120" href="<?= $favicon; ?>-120x120.png">
            <link rel="apple-touch-icon" sizes="144x144" href="<?= $favicon; ?>-144x144.png">
            <link rel="apple-touch-icon" sizes="152x152" href="<?= $favicon; ?>-152x152.png">
            <link rel="apple-touch-icon" sizes="180x180" href="<?= $favicon; ?>-180x180.png">

            <link rel="icon" type="image/png" sizes="192x192" href="<?= $favicon; ?>-192x192.png">
            <link rel="icon" type="image/png" sizes="32x32" href="<?= $favicon; ?>-32x32.png">
            <link rel="icon" type="image/png" sizes="96x96" href="<?= $favicon; ?>-96x96.png">
            <link rel="icon" type="image/png" sizes="16x16" href="<?= $favicon; ?>-16x16.png">
            <?php } ?>

            <?php
            $buffer = ob_get_clean();
            echo $buffer;

        }


        /**
         * Hook analytics code before the closing head tag
         */
        public function analytics_code() {
            global $settings_options;

            if ( $settings_options['custom_code']['analytics'] ) {
                echo '<script type="text/javascript">'. $settings_options['custom_code']['analytics'] .'</script>';
            }
        }


        /**
         * Hook Custom JS code to the footer
         */
        public function custom_js() {
            global $settings_options;

            if ( $settings_options['custom_code']['js'] ) {
                echo '<script type="text/javascript">'. $settings_options['custom_code']['js'] .'</script>';
            }
        }


        /**
         * Custom styling from color scheme 
         * and also custom CSS option
         */
        public function custom_css() {
            $settings_options = get_option( 'dtcwm_settings_options' );
            $color = $settings_options['color_scheme'];

            ob_start();
            ?>
            <style>
                <?php if( $color['body_bg'] ) { ?>
                .page { background-color: <?= $color['body_bg']; ?> }
                <?php } ?>

                .theme-color-bg,
                .is-material .panel .sidemenu-header,
                .swiper-pagination-bullet-active,
                .label-switch input[type=checkbox]:checked+.checkbox,
                .label-switch input[type=checkbox]:checked+.checkbox:after {
                    background-color: <?= $color['primary']; ?>;
                }

                .theme-color-text {
                    color: <?= $color['primary']; ?>;
                }

                .widgets .ui-slider .ui-slider-range {
                    background: none repeat scroll 0 0 <?= $color['primary']; ?>;
                }

                label.label-radio input[type=checkbox]:checked+.item-media i.icon-form-radio, label.label-radio input[type=checkbox]:checked~.item-after i.icon-form-radio, label.label-radio input[type=checkbox]:checked~.item-inner i.icon-form-radio, label.label-radio input[type=radio]:checked+.item-media i.icon-form-radio, label.label-radio input[type=radio]:checked~.item-after i.icon-form-radio, label.label-radio input[type=radio]:checked~.item-inner i.icon-form-radio {
                    border-color: <?= $color['primary']; ?>;
                }

                label.label-radio input[type=checkbox]:checked+.item-media i.icon-form-radio:after, label.label-radio input[type=checkbox]:checked~.item-after i.icon-form-radio:after, label.label-radio input[type=checkbox]:checked~.item-inner i.icon-form-radio:after, label.label-radio input[type=radio]:checked+.item-media i.icon-form-radio:after, label.label-radio input[type=radio]:checked~.item-after i.icon-form-radio:after, label.label-radio input[type=radio]:checked~.item-inner i.icon-form-radio:after {
                    background-color: <?= $color['primary']; ?>;
                }

                .is-ios label.label-radio input[type=checkbox]:checked~.item-inner, 
                .is-ios label.label-radio input[type=radio]:checked~.item-inner {
                    background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2013%2010'%3E%3Cpolygon%20fill%3D'<?= $color['primary']; ?>'%20points%3D'11.6%2C0%204.4%2C7.2%201.4%2C4.2%200%2C5.6%204.4%2C10%204.4%2C10%204.4%2C10%2013%2C1.4%20'%2F%3E%3C%2Fsvg%3E");
                }

                label.label-checkbox input[type=checkbox]:checked+.item-media i.icon-form-checkbox, label.label-checkbox input[type=checkbox]:checked~.item-after i.icon-form-checkbox, label.label-checkbox input[type=checkbox]:checked~.item-inner i.icon-form-checkbox, label.label-checkbox input[type=radio]:checked+.item-media i.icon-form-checkbox, label.label-checkbox input[type=radio]:checked~.item-after i.icon-form-checkbox, label.label-checkbox input[type=radio]:checked~.item-inner i.icon-form-checkbox {
                    border-color: <?= $color['primary']; ?>;
                    background-color: <?= $color['primary']; ?>;
                }

                .is-material .navbar,
                .is-material .toolbar,
                .is-material .searchbar,
                .is-ios .subnavbar .buttons-row .button.active {
                    background-color: <?= $color['navbar_bg']; ?>;
                    color: <?= $color['navbar_text']; ?>;
                }

                <?php if( $color['navbar_bg'] ) { ?>
                .is-ios .navbar {
                    background-color: <?= $color['navbar_bg']; ?>;
                }
                <?php } ?>

                <?php if( $color['navbar_text'] ) { ?>
                .is-ios .navbar {
                    color: <?= $color['navbar_text']; ?>;
                }
                <?php } ?>

                .is-material .navbar .button,
                .is-material .picker-modal .toolbar .button {
                    border: 1px solid <?= $color['navbar_text']; ?>;
                }

                .is-ios .navbar a {
                    color: <?= $color['navbar_text']; ?>;
                }

                .is-ios .subnavbar .buttons-row a {
                    color: <?= $color['navbar_bg']; ?>;
                }

                .onsale {
                    color: <?= $color['label_text']; ?>;
                    background-color: <?= $color['label_bg']; ?>;
                }

                .navbar .cart-badge {
                    color: <?= $color['cart_badge_text']; ?>;
                    background-color: <?= $color['cart_badge_bg']; ?>;
                }

                a {
                    color: <?= $color['links']; ?>;
                }

                .button,
                .is-material .notifications .button.close-notification,
                .is-ios .list-block .item-link.list-button {
                    color: <?= $color['button_bg']; ?>;
                }

                .is-ios .button {
                    border: 1px solid <?= $color['button_bg']; ?>;
                }

                .button.button-fill,
                .button.button-fill.active-state,
                .button.button-fill:hover,
                .button.button-fill:active,
                .button.button-fill:focus {
                    background-color: <?= $color['button_bg']; ?>;
                    color: <?= $color['button_text']; ?>;
                }

                .pagination .page-numbers li span,
                .widgets .woocommerce-product-search input[type=submit] {
                    background-color: <?= $color['button_bg']; ?>;
                    color: <?= $color['button_text']; ?>;
                }


                <?php
                    if ( $settings_options['custom_code']['css'] ) {
                        echo $settings_options['custom_code']['css'];
                    }
                ?>
            </style>

            <?php
            $buffer = ob_get_clean();
            echo dtcwm_minify_css( $buffer );
        }

    }
}

return new DTC_WooMobify_Theme();