<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * DanTheCoder - Innovative Web Solutions
 *
 * @author	DanTheCoder
 * @link	http://danthecoder.com
*/

if ( ! function_exists( 'dtcwm_return_to' ) ) {

	/**
	 * Return the Referer URL
	*/
	function dtcwm_return_to() {
		if ( wp_get_referer() ) {
		    return wp_get_referer();
		}
		else {
		    return get_home_url();
		}
	}
}


if ( ! function_exists( 'dtcwm_minify_css' ) ) {

	/**
	 * Clean and minify customm css
	*/
	function dtcwm_minify_css( $css ) {
		$css = str_replace( array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $css );
		return $css;
	}
}


if ( ! function_exists( 'dtcwm_is_material' ) ) {
	/**
	 * Check if we should load material theme or not
	 * is device android - load material
	 * 
	*/
	function dtcwm_is_material() {
		global $device_detect, $settings_options;

		$theming = $settings_options['theming'];

		if( $device_detect->isAndroidOS() && $theming['android_devices'] == 'material' ) {
			return TRUE;
		}
		elseif( $device_detect->isiOS() && $theming['ios_devices'] == 'material' ) {
			return TRUE;
		}
		elseif ( ! $device_detect->isAndroidOS() && ! $device_detect->isiOS() ) {
			if ( $theming['other_devices'] == 'material' ) {
				return TRUE;
			} else {
				return FALSE;
			}
		} 
		else {
			return FALSE;
		}

	}
}


if ( ! function_exists( 'dtcwm_is_woocommerce_activated' ) ) {
	/**
	 * Check if WooCommerce is activated
	*/
	function dtcwm_is_woocommerce_activated() {
		return class_exists( 'woocommerce' ) ? true : false;
	}
}


if ( ! function_exists( 'dtcwm_show_product_tabs' ) ) {
	/**
	 * Return true if both reviews and related tabs are disabled
	*/
	function dtcwm_show_product_tabs() {
		global $settings_options;
		$tabs = $settings_options['single_product'];
		
		if ( ! $tabs['enable_related'] && ! $tabs['enable_reviews'] ) {
			return false;
		}
		else {
			return true;
		}
	}
}


if ( ! function_exists( 'dtcwm_is_woocommerce_page' ) ) {
	/**
	* Check if the current page is a WooCommerce page
	* @return bool
	*/
	function dtcwm_is_woocommerce_page () {
		if ( is_shop() || is_cart() || is_checkout() || is_account_page() || is_product_category() || is_product_tag() || is_product() ) {
			return true;
		} else {
			return false;
		}
	}
}


if ( ! function_exists( 'dtcem_page_class' ) ) {

	/**
	 * Add additional classes to the page class
	*/
	function dtcem_page_class() {
		global $settings_options;

		$classes = array();

		if ( ! dtcwm_is_material() && $settings_options['enable_toolbar'] ) {
			$classes[] = "toolbar-fixed";
		}

		if ( is_product() && dtcwm_show_product_tabs() ) {
			$classes[] = 'toolbar-fixed with-subnavbar';
		}

		if ( is_search() && dtcwm_is_material() && $settings_options['enable_toolbar'] ) {
			$classes[] = 'toolbar-fixed';
		}

		echo join( ' ', $classes );
		
	}
}