<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * DanTheCoder - Innovative Web Solutions
 *
 * @author	DanTheCoder
 * @link	http://danthecoder.com
*/


/**
 * Homepage
*/
function dtcwm_homepage_layout_hook( ) {
	get_template_part( 'layouts/homepage', 'custom' );
}
add_action( 'woomobify_homepage_layout', 'dtcwm_homepage_layout_hook' );


/**
 * Left Panel
*/
function dtcwm_left_panel_hook( ) {
	get_template_part( 'layouts/left_panel', 'custom' );
}
add_action( 'woomobify_left_panel', 'dtcwm_left_panel_hook' );


/**
 * Navbar
*/
function dtcwm_navbar_hook( $type ) {
	if ( $type == "tabs" ) {
		get_template_part( 'layouts/navbar_tab', 'custom' );
	}
	else {
		get_template_part( 'layouts/navbar', 'custom' );
	}
}
add_action( 'woomobify_navbar', 'dtcwm_navbar_hook' );


/**
 * Navbar Left 
*/
function dtcwm_navbar_left_hook() {
	get_template_part( 'partials/navbar/content', 'navbar_left' );
}
add_action( 'woomobify_navbar_left', 'dtcwm_navbar_left_hook', 50 );


/**
 * Navbar Center 
*/
function dtcwm_navbar_center_hook() {
	get_template_part( 'partials/navbar/content', 'navbar_center' );
}
add_action( 'woomobify_navbar_center', 'dtcwm_navbar_center_hook' );


/**
 * Navbar Right
*/
function dtcwm_navbar_right_hook() {
	get_template_part( 'partials/navbar/content', 'navbar_right' );
}
add_action( 'woomobify_navbar_right', 'dtcwm_navbar_right_hook', 50 );


/**
 * Navbar Tab Links
 * Hook the navbar tab links based on the current page
*/
function dtcwm_navbar_tab_links_hook() {
	// Hook on the checkout page if its not thank you or account pay now
	if ( is_checkout() && empty( get_query_var('order-received') ) && empty( get_query_var('order-pay') ) ) {
		get_template_part( 'partials/navbar/content', 'checkout_tabs' );
	}
	elseif ( is_product() ) {
		get_template_part( 'partials/navbar/content', 'product_tabs' );
	}
	elseif ( is_account_page() && ! is_user_logged_in() ) {
		get_template_part( 'partials/navbar/content', 'login_tabs' );
	}
}
add_action( 'woomobify_navbar_tab_links', 'dtcwm_navbar_tab_links_hook' );


/**
 * Toolbar
*/
function dtcwm_toolbar_hook() {
	global $settings_options;

	if ( is_cart() ) {
		// If cart is not empty
		if ( WC()->cart->get_cart_contents_count() > 0 ) {
			if ( $settings_options['cart']['toolbar_navigation'] ) {
				do_action( 'woocommerce_proceed_to_checkout' );
			} else {
				get_template_part( 'layouts/toolbar', 'custom' );
			}
		}
	}
	// Hook on the checkout and NOT thank you or account pay page
	elseif ( is_checkout() && empty( get_query_var('order-received') ) && empty( get_query_var('order-pay') ) ) {
		if ( $settings_options['checkout']['toolbar_navigation'] ) {
			get_template_part( 'partials/toolbar/content', 'checkout_toolbar' );
		} else {
			get_template_part( 'layouts/toolbar', 'custom' );
		}
	}
	else {
		get_template_part( 'layouts/toolbar', 'custom' );
	}

}
add_action( 'woomobify_toolbar', 'dtcwm_toolbar_hook' );


/**
 * Search Bar
*/
function dtcwm_search_bar_hook() {
    get_template_part( 'partials/content', 'search_bar' );
}
add_action( 'woomobify_search_bar', 'dtcwm_search_bar_hook' );


/**
 * Shop Side Bar
*/
function dtcwm_shop_sidebar_hook() {
	if ( is_search() || is_shop() || is_product_category() ) {
		get_template_part( 'partials/content', 'shop_sidebar' );
	}
}
add_action( 'woomobify_shop_sidebar', 'dtcwm_shop_sidebar_hook' );


/**
 * Categories
*/
function dtcwm_categories_hook() {
	global $settings_options;

	get_template_part( 'layouts/categories', $settings_options['category']['layout'] );
	
}
add_action( 'woomobify_categories', 'dtcwm_categories_hook' );


/**
 * Pages Footer Widget
*/
function dtcwm_footer_hook() {
	get_template_part( 'partials/content', 'footer' );
}
add_action( 'woomobify_footer', 'dtcwm_footer_hook' );


/**
 * Home Page
*/
function dtcwm_homepage_hook() {
	global $settings_options;

	if ( ! empty( $settings_options['homepage']['slot_one'] ) ) {
		get_template_part( 'partials/content', $settings_options['homepage']['slot_one'] );
	}

	if ( ! empty( $settings_options['homepage']['slot_two'] ) ) {
		get_template_part( 'partials/content', $settings_options['homepage']['slot_two'] );
	}

	if ( ! empty( $settings_options['homepage']['slot_three'] ) ) {
		get_template_part( 'partials/content', $settings_options['homepage']['slot_three'] );
	}

	if ( ! empty( $settings_options['homepage']['slot_four'] ) ) {
		get_template_part( 'partials/content', $settings_options['homepage']['slot_four'] );
	}
}
add_action( 'woomobify_homepage', 'dtcwm_homepage_hook' );