<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $settings_options;

?>

<!-- Header More links -->
<div class="popover popover-shop">
    <div class="popover-angle"></div>
    <div class="popover-inner">
        <div class="list-block">
            <ul>
                <li><a href="#" class="list-button item-link open-picker close-popover" data-popover=".popover-shop" data-picker=".picker-sorting"><?= _e( 'Item Sorting', 'woomobify' ); ?></a></li>
                <li><a href="#" class="list-button item-link open-panel close-popover" data-popover=".popover-shop" data-panel="right"><?= _e( 'Filter Items', 'woomobify' ); ?></a></li>
            </ul>
        </div>
    </div>
</div>

<!-- Shop Sorting -->
<div class="picker-modal picker-sorting bg-white">
    <div class="toolbar">
        <div class="toolbar-inner">
            <div class="left"></div>
            <div class="right">
            	<a href="#" class="close-picker button"><?php _e( 'close', 'woomobify' ); ?></a>
            </div>
        </div>
    </div>
    <div class="picker-modal-inner">
        <div class="content-block">
 			
 			<h3 class="mb-1"><?= _e( 'Sort Items By:', 'woomobify' ); ?></h3>

 			<div class="custom-inputs">
				<?php do_action( 'woomobify_product_sorting' ); ?>
			</div>

        </div>
    </div>
</div>

<div class="page <?php dtcem_page_class(); ?>">

    <?php do_action( 'woomobify_navbar'); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

    	<?php
    		// Load search bar
    		if ( is_search() ) {
    			do_action( 'woomobify_search_bar' );
    		}
    	?>

    	<?php
    	// Only load product if search query isn't empty
    	if ( is_search() && ! get_search_query() ) { ?>

			<div class="empty-state">
			    <div class="content-block text-center">

			        <div class="empty-icon">
			        	<?= (dtcwm_is_material() ? '<i class="material-icons">search</i>' : '<i class="f7-icons">search</i>'); ?>
			        </div>
			        <h2><?php _e( 'Search for products', 'woomobify' ); ?></h2>
			        <p><?php _e( 'Click on the search bar above to start your search', 'woocommerce' ); ?></p>

			    </div>
			</div>

    	<?php
    		return;
    	}
    	?>

		<?php do_action( 'woocommerce_before_main_content' ); ?>
	
		<?php if ( have_posts() ) : ?>

			<?php do_action( 'woocommerce_before_shop_loop' ); ?>

			<div class="product-wrapper">
			<?php if ( $settings_options['catalog']['listing_layout'] == 'grid' ) { ?>

				<div class="product-grid">
	    			<div class="row">

						<?php while ( have_posts() ) : the_post(); ?>

							<?php
								do_action( 'woocommerce_shop_loop' );
								wc_get_template_part( 'content', 'product_grid' ); 
							?>

						<?php endwhile; ?>

					</div>
				</div>

			<?php } else { ?>

				<div class="product-list">
			        <div class="list-block media-list">
			            <ul>

							<?php while ( have_posts() ) : the_post(); ?>

								<?php
									do_action( 'woocommerce_shop_loop' );
									wc_get_template_part( 'content', 'product' ); 
								?>

							<?php endwhile; ?>

						</ul>
					</div>
				</div>

			<?php } ?>
			</div>


			<?php do_action( 'woocommerce_after_shop_loop' ); ?>

			<?php do_action( 'woomobify_footer' ); ?>

		<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

			<?php do_action( 'woocommerce_no_products_found' ); ?>

		<?php endif; ?>

		<?php do_action( 'woocommerce_after_main_content' ); ?>

    </div>
</div>