<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.3
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

global $settings_options;

wc_print_notices();
?>

<div class="page  <?php dtcem_page_class(); ?>">

    <?php do_action( 'woomobify_navbar' ); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

        <?php do_action( 'woocommerce_before_cart' ); ?>

        <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
            
            <?php do_action( 'woocommerce_before_cart_table' ); ?>

            <?php if ( wc_coupons_enabled() ) { ?>
                <?php if ( $settings_options['cart']['enable_coupons'] ) { ?>
                <div class="content-block coupon">
                    <div class="row">
                        <div class="col-70 custom-inputs">
                            <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'woocommerce' ); ?>" />
                        </div>
                        <div class="col-30">
                            <input type="submit" class="button button-raised coupon-btn" name="apply_coupon" value="<?php _e( 'Apply', 'woomobify' ); ?>" />
                        </div>
                    </div>
                    <?php do_action( 'woocommerce_cart_coupon' ); ?>
                </div>
                <?php } ?>
            <?php } ?>

            <div class="cart-items product-list">
                <div class="list-block media-list">
                    <ul>

                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                        <?php
                        foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                                ?>

                                <li class="swipeout">
                                    <div class="swipeout-content">
                                        <div class="item-content">

                                            <div class="item-media">
                                                <?php
                                                    $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                                    if ( ! $product_permalink ) {
                                                        echo $thumbnail;
                                                    } else {
                                                        printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail );
                                                    }
                                                ?>
                                            </div>
                                            <div class="item-inner">
                                                <div class="item-title-row">
                                                    <div class="item-title">
                                                        <?php echo apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;'; ?>
                                                    </div>
                                                </div>

                                                <div class="detail-wrap row">
                                                    <div class="col-50">
                                                        <div class="detail-prices">
                                                            <p><?php _e( 'Price', 'woocommerce' ); ?>: <?php echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); ?></p> 
                                                            <p><?php _e( 'Total', 'woocommerce' ); ?>: <?php echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); ?></p>
                                                        </div>
                                                    </div>
                                                    <div class="col-50">
                                                        <?php
                                                            if ( $_product->is_sold_individually() ) {
                                                                $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                                            } else {
                                                                $product_quantity = woocommerce_quantity_input( array(
                                                                    'input_name'  => "cart[{$cart_item_key}][qty]",
                                                                    'input_value' => $cart_item['quantity'],
                                                                    'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
                                                                    'min_value'   => '0',
                                                                ), $_product, false );
                                                            }

                                                            echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
                                                        ?>
                                                    </div>
                                                </div>

                                            </div>

                                        </div>

                                        <?php
                                            // Meta data
                                            echo WC()->cart->get_item_data( $cart_item );
                                        
                                            // Backorder notification
                                            if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                                echo '<div class="backorder_notification">' . esc_html__( 'Available on backorder', 'woocommerce' ) . '</div>';
                                            }
                                        ?>
                                    </div>
                                    <div class="swipeout-actions-right">
                                        <?php
                                            echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                                '<a href="%s" class="remove-swipeout" data-product_id="%s" data-product_sku="%s">' . esc_html__( 'Remove', 'woomobify' ) . '</a>',
                                                esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
                                                esc_attr( $product_id ),
                                                esc_attr( $_product->get_sku() )
                                            ), $cart_item_key );
                                        ?>
                                    </div>

                                </li>

                                <?php
                            }
                        }
                        ?>
                        <?php do_action( 'woocommerce_cart_contents' ); ?>

                        <?php do_action( 'woocommerce_after_cart_contents' ); ?>

                    </ul>
                </div>
            </div>

            <div class="actions">
                <div class="full-cards card">
                    <div class="card-content">

                        <input type="submit" class="button button-big cart-update-button" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'woocommerce' ); ?>" />

                        <?php do_action( 'woocommerce_cart_actions' ); ?>

                        <?php wp_nonce_field( 'woocommerce-cart' ); ?>

                    </div>
                </div>
            </div>

            <?php do_action( 'woocommerce_after_cart_table' ); ?>

        </form>

        <?php if ( $settings_options['cart']['enable_coupons'] ) { ?>
        <div class="cart-collaterals">
            <?php do_action( 'woocommerce_cart_collaterals' ); ?>
        </div>
        <?php } ?>

        <div class="content-block">
            <?php if ( FALSE == $settings_options['cart']['toolbar_navigation'] ) { ?>
            <a href="<?php echo esc_url( wc_get_checkout_url() );?>" class="button button-big button-raised button-fill">
                <?php esc_html_e( 'Proceed to checkout &rarr;', 'woomobify' ); ?>
            </a>
            <?php } ?>
        </div>

        <?php do_action( 'woocommerce_after_cart' ); ?>

        <?php do_action( 'woomobify_footer' ); ?>

    </div>

</div>