<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $dtcwm_options_settings;

wc_print_notices();

?>

<?php 
	// If checkout registration is disabled and not logged in, the user cannot checkout
	if ( ! $checkout->is_registration_enabled() && $checkout->is_registration_required() && ! is_user_logged_in() ) {
?>

<div class="page">

    <?php do_action( 'woomobify_navbar' ); ?>

    <div class="page-content">

		<div class="empty-state">
            <div class="content-block text-center">

                <div class="empty-icon">
                	<?= (dtcwm_is_material() ? '<i class="material-icons">account_circle</i>' : '<i class="f7-icons">person</i>'); ?>
                </div>
                <h2><?php _e( 'Login Required', 'woomobify' ); ?></h2>
                <?php echo apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'woocommerce' ) ); ?>

                <a href="<?= get_permalink( get_option('woocommerce_myaccount_page_id') ); ?>" class="button button-big button-fill button-round button-raised"><?php _e( "Sign In", "woomobify" ); ?></a>
            </div>
        </div>

    </div>
</div>

<?php 
		return;
	}
?>


<form name="checkout" method="post" class="checkout woocommerce-checkout hide-keypad" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">
<div class="page with-subnavbar toolbar-fixed">

    <?php do_action( 'woomobify_navbar', 'tabs' ); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

    	<?php do_action( 'woocommerce_before_checkout_form', $checkout ); ?>

		<div class="tabs">
	
			<div id="billing_tab" class="tab active">
				<?php if ( $checkout->get_checkout_fields() ) : ?>

					<?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

					<?php do_action( 'woocommerce_checkout_billing' ); ?>

					<?php do_action( 'woocommerce_checkout_shipping' ); ?>

					<?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

				<?php endif; ?>
			</div>

			<div id="payment_tab" class="tab">
                <?php do_action( 'woomobify_wc_checkout_payment' ); ?>
			</div>

            <div id="confirm_tab" class="tab">

                <div class="content-block-title"><?php _e( 'Your order', 'woocommerce' ); ?></div>
				<div class="content-block bg-white block-shadow">
					<div class="content-block-inner pt-0 pb-0">
                        <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                        <div id="order_review" class="woocommerce-checkout-review-order">
                            <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                        </div>

                        <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
                    </div>
                </div>

			    <div class="form-row place-order">
					
					<noscript>
						<div class="full-cards card">
							    <div class="card-content">
							        <div class="card-content-inner">

										<p><?php _e( 'Since your browser does not support JavaScript, or it is disabled, please ensure you click the <em>Update Totals</em> button before placing your order. You may be charged more than the amount stated above if you fail to do so.', 'woocommerce' ); ?></p>
										<input type="submit" class="button button-round alt" name="woocommerce_checkout_update_totals" value="<?php esc_attr_e( 'Update totals', 'woocommerce' ); ?>" />
									
									</div>
								</div>
						</div>
					</noscript>

					<?php wc_get_template( 'checkout/terms.php' ); ?>

					<div class="content-block">
						<?php do_action( 'woocommerce_review_order_before_submit' ); ?>

						<?php if ( FALSE == $dtcwm_options_settings['checkout']['toolbar_navigation'] ) { ?>
							<input id="show_complete_btn" type="submit" class="button button-big button-raised button-fill" name="woocommerce_checkout_place_order" value="<?php _e( 'Place Order &rarr;', 'woomobify' ); ?>" style="display: none;">
						<?php } ?>

						<?php do_action( 'woocommerce_review_order_after_submit' ); ?>
					</div>

					<?php wp_nonce_field( 'woocommerce-process_checkout' ); ?>
				</div>

            </div>

		</div>

		<?php do_action( 'woocommerce_after_checkout_form', $checkout ); ?>

		<?php do_action( 'woomobify_footer' ); ?>

	</div>
</div>
</form>