<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>

<div class="page <?php if( ! dtcwm_is_material() ) { ?>toolbar-fixed<?php } ?>">

    <?php do_action( 'woomobify_navbar' ); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

		<?php if ( $order ) : ?>

			<div class="full-cards card">
			    <div class="card-content">
			        <div class="card-content-inner">

						<?php if ( $order->has_status( 'failed' ) ) : ?>

					        <div class="block-heading text-center">
								<span class="text-error"><?= (dtcwm_is_material() ? '<i class="material-icons">cancel</i>' : '<i class="f7-icons">close_round</i>'); ?></span>
								<h2><?php _e( 'Order Failed!', 'woomobify' ); ?></h2>
								<p><?php _e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction. Please attempt your purchase again.', 'woocommerce' ); ?></p>
							</div>

							<div class="row mt-3">
								<div class="col-50">
									<?php if ( is_user_logged_in() ) : ?>
										<a href="<?php echo esc_url( wc_get_page_permalink( 'myaccount' ) ); ?>" class="button button-raised"><?php _e( 'My account', 'woocommerce' ); ?></a>
									<?php endif; ?>
								</div>
								<div class="col-50">
									<a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="button button-raised button-fill"><?php _e( 'Pay', 'woocommerce' ) ?></a>
								</div>
							</div>

						<?php else : ?>

							<div class="block-heading text-center">
								<span class="text-success"><?= (dtcwm_is_material() ? '<i class="material-icons">check_circle</i>' : '<i class="f7-icons">check_round</i>'); ?></span>
								<h2><?php _e( 'Thank you!', 'woomobify' ); ?></h2>
								<p><?php _e( 'Your order has been received', 'woomobify' ); ?></p>
							</div>

							<div class="list-block pt-2">
							    <ul>
									<li>
									    <div class="item-content">
									        <div class="item-inner">
									            <div class="item-title">
									            	<?php _e( 'Order number:', 'woocommerce' ); ?>
									            </div>
									            <div class="item-after">
									            	<strong><?php echo $order->get_order_number(); ?></strong>
									            </div>
									        </div>
									    </div>
									</li>
									<li>
									    <div class="item-content">
									        <div class="item-inner">
									            <div class="item-title">
									                <?php _e( 'Date:', 'woocommerce' ); ?>
									            </div>
									            <div class="item-after">
									            	<?php echo wc_format_datetime( $order->get_date_created() ); ?>
									            </div>
									        </div>
									    </div>
									</li>
									<li>
									    <div class="item-content">
									        <div class="item-inner">
									            <div class="item-title">
									                <?php _e( 'Total:', 'woocommerce' ); ?>
									            </div>
									            <div class="item-after">
									            	<strong><?php echo $order->get_formatted_order_total(); ?></strong>
									            </div>
									        </div>
									    </div>
									</li>

									<?php if ( $order->get_payment_method_title() ) : ?>
									<li>
									    <div class="item-content">
									        <div class="item-inner">
									            <div class="item-title">
									                <?php _e( 'Payment method:', 'woocommerce' ); ?>
									            </div>
									            <div class="item-after">
									            	<?php echo wp_kses_post( $order->get_payment_method_title() ); ?>
									            </div>
									        </div>
									    </div>
									</li>
									<?php endif; ?>

							    </ul>
							</div>

						<?php endif; ?>

			    	</div>
			    </div>

			    <div id="payment-instruction"><?php do_action( 'woocommerce_thankyou_' . $order->get_payment_method(), $order->get_id() ); ?></div>
			
			</div> 

			<?php do_action( 'woocommerce_thankyou', $order->get_id() ); ?>

		<?php else : ?>

			<div class="full-cards card">
			    <div class="card-content">
			        <div class="card-content-inner">

						<div class="block-heading text-center">
							<span class="text-success"><?= (dtcwm_is_material() ? '<i class="material-icons">check_circle</i>' : '<i class="f7-icons">check_round</i>'); ?></span>
							<h2><?php _e( 'Thank you!', 'woomobify' ); ?></h2>
							<p><?php _e( 'Your order has been received', 'woomobify' ); ?></p>
						</div>

			        </div>
			    </div>
			</div>

		<?php endif; ?>

		<?php do_action( 'woomobify_footer' ); ?>

    </div>

</div>