<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @author      WooThemes
 * @package     WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly
}

global $settings_options, $product, $post;;
?>

<?php
  /**
   * woocommerce_before_single_product hook.
   *
   * @hooked wc_print_notices - 10
   */
   do_action( 'woocommerce_before_single_product' );

   if ( post_password_required() ) {
    echo get_the_password_form();
    return;
   }
?>

<div id="product-<?php the_ID(); ?>" <?php post_class(); ?>>
    <div class="page <?php dtcem_page_class(); ?>">

        <?php
            // Load tabs header or normal header
            if ( dtcwm_show_product_tabs() ) {
               do_action( 'woomobify_navbar', 'tabs' );
            } else {
                do_action( 'woomobify_navbar' );
            } 
        ?>

        <?php do_action( 'woomobify_toolbar' ); ?>

        <div class="page-content keep-toolbar-on-scroll">
            <div class="tabs">

                <div id="overview_tab" class="single-product tab active">

                    <?php
                        /**
                         * woocommerce_before_single_product_summary hook.
                         *
                         * @hooked woocommerce_show_product_sale_flash - 10
                         * @hooked woocommerce_show_product_images - 20
                         */
                        do_action( 'woocommerce_before_single_product_summary' );
                    ?>

                    <div class="content-block mt-0 bg-white block-shadow">
                        <div class="content-block-inner">
                        <?php
                            /**
                             * woocommerce_single_product_summary hook.
                             *
                             * @hooked woocommerce_template_single_title - 5
                             * @hooked woocommerce_template_single_rating - 10
                             * @hooked woocommerce_template_single_price - 10
                             * @hooked woocommerce_template_single_excerpt - 20
                             * @hooked woocommerce_template_single_add_to_cart - 30
                             * @hooked woocommerce_template_single_meta - 40
                             * @hooked woocommerce_template_single_sharing - 50
                             * @hooked WC_Structured_Data::generate_product_data() - 60
                             */
                            do_action( 'woocommerce_single_product_summary' );
                        ?>
                        </div>
                    </div>

                    <?php if( $post->post_content || $product->has_attributes() || $product->has_dimensions() || $product->has_weight() ) { ?>
                        <div class="content-block mt-0 bg-white  block-shadow">
                            <div class="content-block-inner pb-0">

                                <?php
                                    $description_heading = esc_html( apply_filters( 'woocommerce_product_description_heading', __( 'Description', 'woocommerce' ) ) );
                                    $additional_heading = esc_html( apply_filters( 'woocommerce_product_additional_information_heading', __( 'Additional information', 'woocommerce' ) ) );
                                ?>

                                <?php if ( $post->post_content ) {
                                    if ( $description_heading ) {
                                        echo "<h3 class='mt-0'>".$description_heading."</h3>";
                                    }
                                }
                                ?>
                                <?php the_content(); ?>


                                <?php
                                // Check if product has attributes, dimensions or weight
                                if( $product->has_attributes() || $product->has_dimensions() || $product->has_weight() ) {
                                    if ( $additional_heading ) {
                                        echo "<h3 class='mt-0 mb-0'>".$additional_heading."</h3>";
                                    }
                                } ?>
                                <?php do_action( 'woocommerce_product_additional_information', $product ); ?>

                            </div>
                        </div>
                    <?php } ?>

                </div>


                <?php 
                    // Hook the review template here
                    if ( $settings_options['single_product']['enable_reviews'] ) {
                        do_action( 'woomobify_wc_product_review' );
                    } 
                ?>


                <?php if ( $settings_options['single_product']['enable_related'] ) { ?>
                <div id="related_tab" class="tab">
                    <?php do_action( 'woomobify_wc_product_related' ); ?>
                </div>
                <?php } ?>

            </div>

            <?php
                /**
                 * woocommerce_after_single_product_summary hook.
                 *
                 * @hooked woocommerce_output_product_data_tabs - 10
                 * @hooked woocommerce_upsell_display - 15
                 * @hooked woocommerce_output_related_products - 20
                 */
                do_action( 'woocommerce_after_single_product_summary' );
            ?>

            <?php do_action( 'woocommerce_after_single_product' ); ?>

            <?php do_action( 'woomobify_footer' ); ?>

        </div> 

    </div>
</div>