<?php
/**
 * Downloads
 *
 * Shows downloads on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/downloads.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$downloads     = WC()->customer->get_downloadable_products();
$has_downloads = (bool) $downloads;
?>

<div class="page">

	<?php do_action( 'woomobify_navbar' ); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

		<?php do_action( 'woocommerce_before_account_downloads', $has_downloads ); ?>

		<?php if ( $has_downloads ) : ?>

			<?php do_action( 'woocommerce_before_available_downloads' ); ?>

			<div class="list-block cards-list">
				<ul>

				<?php foreach ( $downloads as $download ) : ?>
					<li class="card">
						<div class="card-content">
							<div class="card-content-inner">

								<strong><?php echo esc_html( $download['product_name'] ); ?></strong>
								<div>
									<?php _e( 'Remaining:', 'woomobify' ); ?> 
									<?php echo is_numeric( $download['downloads_remaining'] ) ? esc_html( $download['downloads_remaining'] ) : __( '&infin;', 'woocommerce' ); ?>
								</div>
								<div>
									<?php _e( 'Expires:', 'woomobify' ); ?> 
									<?php if ( ! empty( $download['access_expires'] ) ) : ?>
										<time datetime="<?php echo date( 'Y-m-d', strtotime( $download['access_expires'] ) ); ?>" title="<?php echo esc_attr( strtotime( $download['access_expires'] ) ); ?>"><?php echo date_i18n( get_option( 'date_format' ), strtotime( $download['access_expires'] ) ); ?></time>
									<?php else : ?>
										<?php _e( 'Never', 'woocommerce' ); ?>
									<?php endif; ?>
								</div>

							</div>
						</div>
						<div class="card-footer">
							<a class="button" href="<?php echo esc_url( get_permalink( $download['product_id'] ) ); ?>"><?php _e( 'View', 'woomobify' ); ?></a>
							<?php
								$actions = array(
									'download'  => array(
										'url'  => $download['download_url'],
										'name' => __( 'Download', 'woocommerce' ),
									),
								);
								if ( $actions = apply_filters( 'woocommerce_account_download_actions', $actions, $download ) ) {
									foreach ( $actions as $key => $action ) {
										echo '<a href="' . esc_url( $action['url'] ) . '" class="button woocommerce-Button ' . sanitize_html_class( $key ) . '">' . esc_html( $action['name'] ) . '</a>';
									}
								}
							?>
						</div>
					</li>
				<?php endforeach; ?>
				
				</ul>
			</div>

			<?php do_action( 'woocommerce_after_available_downloads' ); ?>

		<?php else : ?>

			<div class="empty-state">
	            <div class="content-block text-center">

	                <div class="empty-icon">
	                	<?= (dtcwm_is_material() ? '<i class="material-icons">file_download</i>' : '<i class="f7-icons">download</i>'); ?>
	                </div>

	                <h2><?php _e( 'Downloads', 'woomobify' ); ?></h2>
	                <p><?php esc_html_e( 'No downloads available yet.', 'woocommerce' ); ?></p>

				</div>
	        </div>

		<?php endif; ?>

		<?php do_action( 'woocommerce_after_account_downloads', $has_downloads ); ?>

		<?php do_action( 'woomobify_footer' ); ?>

	</div>
</div>