<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

?>

<?php wc_print_notices(); ?>

<div class="page <?php if ( get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ) {echo 'with-subnavbar toolbar-fixed';} ?>">

	<?php 
		if ( get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ) {
			do_action( 'woomobify_navbar', 'tabs' );
		} else {
			do_action( 'woomobify_navbar' );
		}
	?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

		<div class="tabs">
			<div id="login_tab" class="tab active">
				
				<?php do_action( 'woocommerce_before_customer_login_form' ); ?>

				<div class="content-block mt-0 bg-white block-shadow">
					<div class="content-block-inner custom-inputs">

						<div class="text-center">
							<h2 class="mb-0"><?php _e( 'Sign In', 'woomobify' ); ?></h2>
							<p><?php _e( 'Log into your account', 'woomobify' ); ?></p>
						</div>

						<form class="woocomerce-form woocommerce-form-login login" method="post">

							<?php do_action( 'woocommerce_login_form_start' ); ?>

							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="username"><?php _e( 'Username or email address', 'woocommerce' ); ?> <span class="required">*</span></label>
								<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="username" value="<?php if ( ! empty( $_POST['username'] ) ) echo esc_attr( $_POST['username'] ); ?>" />
							</p>
							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="password"><?php _e( 'Password', 'woocommerce' ); ?> <span class="required">*</span></label>
								<input class="woocommerce-Input woocommerce-Input--text input-text" type="password" name="password" id="password" />
							</p>

							<?php do_action( 'woocommerce_login_form' ); ?>

							<div class="row my-3">
								<div class="col-20">
									<label class="label-switch">
										<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" />
										<div class="checkbox"></div>
									</label>
								</div>
								<div class="col-80">
									<div class="remember-label"><?php _e( 'Remember me', 'woocommerce' ); ?></div>
								</div>
							</div> 

							<div class="my-2">
								<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
								<input type="submit" class="button button-big button-fill button-raised" name="login" value="<?php esc_attr_e( 'Login', 'woocommerce' ); ?>" />
							</div>

							<div class="lost_password pt-2 text-center">
								<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php _e( 'Lost your password?', 'woocommerce' ); ?></a>
							</div>

							<?php do_action( 'woocommerce_login_form_end' ); ?>

						</form>

					</div>
				</div>

				<?php do_action( 'woocommerce_after_customer_login_form' ); ?>

			</div>

			<?php if ( get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ) : ?>
			<div id="register_tab" class="tab">

				<div class="content-block mt-0 bg-white block-shadow">
					<div class="content-block-inner custom-inputs">

						<div class="text-center">
							<h2 class="mb-0"><?php _e( 'Sign Up!', 'woomobify' ); ?></h2>
							<p><?php _e( 'Log into your account', 'woomobify' ); ?></p>
						</div>

						<form method="post" class="register">

							<?php do_action( 'woocommerce_register_form_start' ); ?>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

								<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
									<label for="reg_username"><?php _e( 'Username', 'woocommerce' ); ?> <span class="required">*</span></label>
									<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="reg_username" value="<?php if ( ! empty( $_POST['username'] ) ) echo esc_attr( $_POST['username'] ); ?>" />
								</p>

							<?php endif; ?>

							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="reg_email"><?php _e( 'Email address', 'woocommerce' ); ?> <span class="required">*</span></label>
								<input type="email" class="woocommerce-Input woocommerce-Input--text input-text" name="email" id="reg_email" value="<?php if ( ! empty( $_POST['email'] ) ) echo esc_attr( $_POST['email'] ); ?>" />
							</p>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

								<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
									<label for="reg_password"><?php _e( 'Password', 'woocommerce' ); ?> <span class="required">*</span></label>
									<input type="password" class="woocommerce-Input woocommerce-Input--text input-text" name="password" id="reg_password" />
								</p>

							<?php endif; ?>

							<!-- Spam Trap -->
							<div style="<?php echo ( ( is_rtl() ) ? 'right' : 'left' ); ?>: -999em; position: absolute;"><label for="trap"><?php _e( 'Anti-spam', 'woocommerce' ); ?></label><input type="text" name="email_2" id="trap" tabindex="-1" autocomplete="off" /></div>

							<?php do_action( 'woocommerce_register_form' ); ?>

							<?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
							<input type="submit" class="button button-big button-fill button-raised" name="register" value="<?php esc_attr_e( 'Register', 'woocommerce' ); ?>" />
							
							<?php do_action( 'woocommerce_register_form_end' ); ?>

						</form>

					</div>
				</div>

			</div>
			<?php endif; ?>

		</div>

    	<?php do_action( 'woomobify_footer' ); ?>

    </div>
</div>		