<?php
/**
 * My Account navigation
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/navigation.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $settings_options;

do_action( 'woocommerce_before_account_navigation' );
?>

<?php if ( $settings_options['account']['dashboard_layout'] == 'list' ) { ?>
    <div class="list-block bg-white block-shadow woocommerce-MyAccount-navigation">
        <ul>
            <?php foreach ( wc_get_account_menu_items() as $endpoint => $label ) : ?>
            <li class="<?php echo wc_get_account_menu_item_classes( $endpoint ); ?>">
                <a href="<?php echo esc_url( wc_get_account_endpoint_url( $endpoint ) ); ?>" class="item-link item-content">
                    <div class="item-inner">
                        <div class="item-title"><?php echo esc_html( $label ); ?></div>
                    </div>
                </a>
            </li>
            <?php endforeach; ?>
        </ul>
    </div>

<?php } else { ?>

    <!-- Menu Nav - Grid -->
    <div class="content-block nav-grid  bg-white block-shadow">
        <div class="content-block-inner">

            <div class="row">
                <div class="col-50">
                    <a href="<?php echo esc_url( wc_get_account_endpoint_url( 'orders' ) ); ?>">
                        <?= (dtcwm_is_material() ? '<i class="material-icons">shopping_cart</i>' : '<i class="icon dtc-ios-cart"></i>'); ?>
                        <span><?php _e( 'Orders', 'woomobify' ); ?></span>
                    </a>
                </div>
                <div class="col-50">
                    <a href="<?php echo esc_url( wc_get_account_endpoint_url( 'downloads' ) ); ?>">
                        <?= (dtcwm_is_material() ? '<i class="material-icons">file_download</i>' : '<i class="f7-icons">download</i>'); ?>
                        <span><?php _e( 'Downloads', 'woomobify' ); ?></span>
                    </a>
                </div>  
            </div>

            <div class="row">
                <div class="col-50">
                    <a href="<?php echo esc_url( wc_get_account_endpoint_url( 'edit-address' ) ); ?>">
                        <?= (dtcwm_is_material() ? '<i class="material-icons">description</i>' : '<i class="f7-icons">document_text</i>'); ?>
                        <span><?php _e( 'Addresses', 'woomobify' ); ?></span>
                    </a>
                </div>
                <div class="col-50">
                    <a href="<?php echo esc_url( wc_get_account_endpoint_url( 'edit-account' ) ); ?>">
                        <?= (dtcwm_is_material() ? '<i class="material-icons">people</i>' : '<i class="f7-icons">persons</i>'); ?>
                        <span><?php _e( 'Account Details', 'woomobify' ); ?></span>
                    </a>
                </div>  
            </div>

        </div>
    </div>

<?php } ?>

<?php do_action( 'woocommerce_after_account_navigation' ); ?>
