<?php
/**
 * Orders
 *
 * Shows orders on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/orders.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>

<div class="page">

	<?php do_action( 'woomobify_navbar' ); ?>

    <?php do_action( 'woomobify_toolbar' ); ?>

    <div class="page-content">

		<?php do_action( 'woocommerce_before_account_orders', $has_orders ); ?>

		<?php if ( $has_orders ) : ?>

			<div class="list-block cards-list">
				<ul>

				<?php foreach ( $customer_orders->orders as $customer_order ) :
					$order      = wc_get_order( $customer_order );
					$item_count = $order->get_item_count();
				?>

					<li class="card">
						<div class="card-content">
							<div class="card-content-inner">

								<div class="pull-left">
									<strong><?php echo _x( '#', 'hash before order number', 'woocommerce' ) . $order->get_order_number(); ?></strong>
								</div>
								<div class="pull-right">
									<time datetime="<?php echo esc_attr( $order->get_date_created()->date( 'c' ) ); ?>"><?php echo esc_html( wc_format_datetime( $order->get_date_created() ) ); ?></time>
								</div>
								<div class="clearfix mb-2"></div>

								<div>
									<?php _e( 'Status:', 'woomobify' ); ?> <?php echo esc_html( wc_get_order_status_name( $order->get_status() ) ); ?>
								</div>
								<div>
									<?php _e( 'Total:', 'woomobify' ); ?>
									<?php
										/* translators: 1: formatted order total 2: total order items */
										printf( _n( '<strong>%1$s</strong> for %2$s item', '<strong>%1$s</strong> for %2$s items', $item_count, 'woocommerce' ), $order->get_formatted_order_total(), $item_count );
									?>
								</div>

							</div>
						</div>
						<div class="card-footer">
							<?php
								$actions = array(
									'pay'    => array(
										'url'  => $order->get_checkout_payment_url(),
										'name' => __( 'Pay', 'woocommerce' ),
									),
									'view'   => array(
										'url'  => $order->get_view_order_url(),
										'name' => __( 'View', 'woocommerce' ),
									),
									'cancel' => array(
										'url'  => $order->get_cancel_order_url( wc_get_page_permalink( 'myaccount' ) ),
										'name' => __( 'Cancel', 'woocommerce' ),
									),
								);

								if ( ! $order->needs_payment() ) {
									unset( $actions['pay'] );
								}

								if ( ! in_array( $order->get_status(), apply_filters( 'woocommerce_valid_order_statuses_for_cancel', array( 'pending', 'failed' ), $order ) ) ) {
									unset( $actions['cancel'] );
								}

								if ( $actions = apply_filters( 'woocommerce_my_account_my_orders_actions', $actions, $order ) ) {
									foreach ( $actions as $key => $action ) {
										echo '<a href="' . esc_url( $action['url'] ) . '">' . esc_html( $action['name'] ) . '</a>';
									}
								}
							?>
						</div>
					</li>

				<?php endforeach; ?>

				</ul>
			</div>

			<?php do_action( 'woocommerce_before_account_orders_pagination' ); ?>

			<?php if ( 1 < $customer_orders->max_num_pages ) : ?>
				<div class="woocommerce-pagination woocommerce-pagination--without-numbers woocommerce-Pagination">
					<?php if ( 1 !== $current_page ) : ?>
						<a class="woocommerce-button woocommerce-button--previous woocommerce-Button woocommerce-Button--previous button" href="<?php echo esc_url( wc_get_endpoint_url( 'orders', $current_page - 1 ) ); ?>"><?php _e( 'Previous', 'woocommerce' ); ?></a>
					<?php endif; ?>

					<?php if ( intval( $customer_orders->max_num_pages ) !== $current_page ) : ?>
						<a class="woocommerce-button woocommerce-button--next woocommerce-Button woocommerce-Button--next button" href="<?php echo esc_url( wc_get_endpoint_url( 'orders', $current_page + 1 ) ); ?>"><?php _e( 'Next', 'woocommerce' ); ?></a>
					<?php endif; ?>
				</div>
			<?php endif; ?>

		<?php else : ?>

			<div class="empty-state">
	            <div class="content-block text-center">

	                <div class="empty-icon">
	                	<?= (dtcwm_is_material() ? '<i class="material-icons">shopping_cart</i>' : '<i class="icon dtc-ios-cart"></i>'); ?>
	                </div>

	                <h2><?php _e( 'Orders', 'woomobify' ); ?></h2>
	                <p><?php _e( 'No order has been made yet.', 'woocommerce' ); ?></p>

				</div>
	        </div>

		<?php endif; ?>

		<?php do_action( 'woocommerce_after_account_orders', $has_orders ); ?>

		<?php do_action( 'woomobify_footer' ); ?>

	</div>
</div>