<?php
/*
Plugin Name: WooMobify
Plugin URI: http://woomobify.com
Description: WooMobify is a complete mobile solution, packed with powerful features that are designed to push your WooCommerce store to another level.
Version: 1.5.8.1
Author: WooMobify
Author URI: http://woomobify.com
*/

$dtcwm_settings_options = get_option( 'dtcwm_settings_options', [] );
$dtcwm_settings_options[ 'license_key' ] = 'nulled';
$dtcwm_settings_options[ 'enable_woomobify' ] = 1;
update_option( 'dtcwm_settings_options', $dtcwm_settings_options );

if ( ! defined( 'WPINC' ) ) die;
if ( ! class_exists( 'DTC_WooMobify_Core' ) ) die;	

// Set the version
define( 'WOOMOBIFY_VERSION', '1.5.9.1' );


class DTC_WooMobify_Core {

	protected static $instance = null;
	protected $globals;

	protected static $plugin_name 			= 'WooMobify';
	protected static $plugin_slug 			= 'dtc-woomobify';
	protected static $core_options_key		= 'dtcwm_core_options';
	protected static $settings_options_key 	= 'dtcwm_settings_options';
	protected static $plugin_connect_url 	= 'http://connect.woomobify.com/';
	protected static $theme_folder_name		= 'woomobify';

	protected $plugin_dir;
	protected $plugin_path;
	protected $plugin_url;

	public function __construct() {
		register_activation_hook( __FILE__, array( 'DTC_WooMobify_Core', 'activate' ) );
		register_uninstall_hook( __FILE__, array( 'DTC_WooMobify_Core', 'uninstall' ) );
		//register_deactivation_hook( __FILE__, array( 'DTC_WooMobify_Core', 'deactivate' ) );

		add_action( 'admin_menu', array( $this, 'menu_options') );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts') );
		add_filter( 'plugin_action_links', array( $this, 'action_links'), 10, 2 );
		add_action( 'setup_theme', array($this, 'load_woomobify_theme') );
		add_action( 'widgets_init', array( $this, 'set_widgets' ) );
	}


	/**
	 * Set the instance
	*/
	public static function instance() {
		static $globals;
		if ( self::$instance == null ) {
			self::$instance = new self;
			$globals = self::$instance->set_globals();
			self::$instance->load_includes();
		}
		return $globals;
	}


	/**
	 * Set Globals
	*/
	public function set_globals() {
		$this->plugin_file = __FILE__;
		$this->plugin_dir = dirname( plugin_basename( $this->plugin_file ) );
		$this->plugin_path = plugin_dir_path( $this->plugin_file );
		$this->plugin_url =	plugin_dir_url( $this->plugin_file );

		$globals = array (
			'plugin_name' 			=> self::$plugin_name,
			'plugin_slug' 			=> self::$plugin_slug,
			'plugin_dir' 			=> $this->plugin_dir,
			'plugin_path' 			=> $this->plugin_path,
			'plugin_url'			=> $this->plugin_url,
			'core_options_key'		=> self::$core_options_key,
			'settings_options_key'	=> self::$settings_options_key,
			'plugin_connect_url'	=> self::$plugin_connect_url,
			'theme_folder_name'		=> self::$theme_folder_name
		);
		
		$this->globals = $globals;
		return $globals;
	}


	/**
	 * Set up the global options pages
	*/
	public function menu_options() {
		add_menu_page( $this->globals['plugin_name'], $this->globals['plugin_name'], 'manage_options', $this->globals['plugin_slug'], array($this, 'options_page'), $this->globals['plugin_url'].'assets/images/nav-icon.png', 50 );
	}

	public function options_page() {
		if( ! current_user_can('manage_options') )	{
			wp_die( __('You do not have sufficient permissions to access this page.', 'woomobify') );
		}

		$this->page_tabs['dashboard']	= '<i class="icon dtc-display position-left"></i> '. __( 'Dashboard', 'woomobify' );
		$this->page_tabs['settings']	= '<i class="icon dtc-equalizer position-left"></i> '. __( 'Settings', 'woomobify' );

		include_once( $this->globals['plugin_path'] . 'views/options-page.php' );
	}


	/**
	 * Enqueue CSS and JS
	*/
	public function enqueue_scripts( $hook ) {
		if( $hook != 'toplevel_page_dtc-woomobify' ) 
			return;

		wp_enqueue_media();

		// Styles
		wp_enqueue_style( 'dtcwm-bs-style', $this->globals['plugin_url'] . 'assets/css/bootstrap.min.css' );
		wp_enqueue_style( 'dtcwm-style', $this->globals['plugin_url'] . 'assets/css/style.css' );

		// Scripts
		wp_enqueue_script( 'dtcwm-bs-tether', $this->globals['plugin_url'] . 'assets/js/tether.min.js');
		wp_enqueue_script( 'dtcwm-bs-script', $this->globals['plugin_url'] . 'assets/js/bootstrap.min.js');
		wp_enqueue_script( 'dtcwm-ace-script', $this->globals['plugin_url'] . 'assets/js/ace/ace.js');
		wp_enqueue_script( 'dtcwm-script', $this->globals['plugin_url'] . 'assets/js/app.js', array('jquery') );
		
		wp_localize_script( 'dtcwm-script', 'dtcwm_admin_vars', array(
				'dtcwm_images_action' => wp_create_nonce('dtcwm_images_nonce')
			)
		);
	}


	/**
	 * Load necessary files
	*/
	public function load_includes() {
		if ( is_admin() ) {
			include_once( $this->globals['plugin_path'] . 'includes/class-settings.php' );
			include_once( $this->globals['plugin_path'] . 'includes/class-helpers.php' );
		}
	}


	/**
	 * Plugin page action links
	*/
	public function action_links( $links, $file ) {
	    static $this_plugin;

	    if ( ! $this_plugin ) {
	        $this_plugin = plugin_basename( __FILE__ );
	    }

	    if ( $file == $this_plugin ) {
	    	$settings = '<a href="' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page='. self::$plugin_slug .'">Settings</a>';
	        array_unshift( $links, $settings );
	    }

	    return $links;
	}


	/**
	 * Load necessary files
	*/
	public function load_woomobify_theme() {
		if ( ! is_admin() ) {

			// Check if WooCommerce is active
			if ( class_exists( 'WooCommerce' ) ) {

				include_once( $this->globals['plugin_path'] . 'includes/class-mobile-detect.php' );
				$detect_device = new DTC_Mobile_Detect;
				$option = get_option( self::$settings_options_key );

				// Load for mobile
				if ( $option['enable_woomobify'] ) {
					if ( $detect_device->isMobile() ) {

						add_filter('template', create_function( '$t', 'return "'. $this->globals['theme_folder_name']. '";' ) );
						add_filter('stylesheet', create_function( '$s', 'return "'. $this->globals['theme_folder_name'] .'";' ) );
					
					}
				}

				// Load for tablets
				if ( $option['enable_tablet'] ) {
					if ( $detect_device->isTablet() ) {

						add_filter('template', create_function( '$t', 'return "'. $this->globals['theme_folder_name']. '";' ) );
						add_filter('stylesheet', create_function( '$s', 'return "'. $this->globals['theme_folder_name'] .'";' ) );
					
					}
				}
			}

		}
	}



    /**
     * Register widget area
    */
	public function set_widgets() {
        $widget_args['sidebar'] = array(
            'name'          => __( 'WooMobify Shop Sidebar', 'woomobify' ),
            'id'            => 'dtcwm-shop-sidebar',
            'description'   => __( 'Widgets added to this region will appear on the right panel on the shop page.', 'woomobify' )
        );

        $widget_args['footer'] = array(
            'name'          => __( 'WooMobify Footer', 'woomobify' ),
            'id'            => 'dtcwm-footer',
            'description'   => __( 'Widgets added to this region will appear before the footer copyright.', 'woomobify' )
        );

        foreach ( $widget_args as $sidebar => $args ) {
            $widget_tags = array(
                'before_widget' => '<div id="%1$s" class="widget %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<span class="gamma widget-title">',
                'after_title'   => '</span>'
            );
            
            register_sidebar( $args );
        }
    }
    

	/**
	 * Activation Hook
	*/
	public static function activate() {
		$wm_helpers	= new DTC_WooMobify_Helpers();
		$settings_option_chk = get_option( self::$settings_options_key );

		// Are our options saved in the DB? If not save
		if( ! $settings_option_chk ) {
			add_option( self::$settings_options_key, $wm_helpers->settings_default_options() );
		}

		// If WooMobify is already activated
		// Run set up
		if ( $settings_option_chk['license_key'] ) {
			$license_key = $settings_option_chk['license_key'];
		
			$response = wp_remote_get( self::$plugin_connect_url.'license-verify/'.$license_key );
			if( is_array($response) ) {
				$result = json_decode( $response['body'] );

				// Validate the key
				if ( $result->status == FALSE ) {
					//echo json_encode( array('success' => false, 'message' => $result->message) );
				} else {

					// Complete the set up
					$wm_helpers = new DTC_WooMobify_Helpers();

					// Update settings
					$settings_option_chk['enable_woomobify'] = 1;
					update_option( self::$settings_options_key, $settings_option_chk );

					// Download and install the theme
					$download_url = self::$plugin_connect_url.'/download-woomobify/'.$license_key;
					$wm_helpers->delete_dir( get_theme_root() . '/'. self::$theme_folder_name );
					$install_theme = $wm_helpers->file_downloader( $download_url, get_theme_root() );

				}
			}

		}

	}


	/**
	 * Uninstall Hook
	*/
	public static function uninstall() {
		$wm_helpers	= new DTC_WooMobify_Helpers();
		$settings_options = get_option( self::$settings_options_key );

		// Delete options
		if ( $settings_options['save_settings'] == FALSE ) {
			delete_option( self::$settings_options_key );
		}

		// Deactivate
		$deactivate = wp_remote_get( self::$plugin_connect_url.'license-deactivate/'.$settings_options['license_key'] );
		if( is_array($deactivate) ) {
			$result = json_decode( $deactivate['body'] );

			if ( $result->status ) {
				$settings_options['license_key'] = '';
				update_option( self::$settings_options_key, $settings_options );

				$wm_helpers->delete_dir( get_theme_root() . '/'. self::$theme_folder_name );
			}

		}

	}

}

DTC_WooMobify_Core::instance();